import { DialogSOP } from '../../libappsop/dialogsop';
import { DropDownListSOP } from '../../libappsop/dropdownlistsop';
import { GanttChartSOP } from '../../libappsop/ganttchartsop';

export interface DialogCapacityPlanningEditCalendarFields {
  Calendar?: string;
}

export class DialogCapacityPlanningEditCalendar extends DialogSOP<DialogCapacityPlanningEditCalendarFields> {
  public gcCapacityPlanningEditCalendar = new GanttChartCapacityPlanningEditCalendar();

  public ddlCalendar = new DropDownListSOP('selCalendar');

  public constructor() {
    super('LibCal_dlgEditCalendar', 'btnOK');

    // Set UI element mapping to pair the UI name to the UI element for use in DialogSOP to find the UI object to set value or verify value
    // This prevents each new Dialog to duplicate code just to set/verify UI element value
    this._uiMap.set('Calendar', this.ddlCalendar);
  }

  public override async waitUntilPresent(ignorePendingAsyncQuill?: boolean): Promise<void> {
    await super.waitUntilPresent(ignorePendingAsyncQuill);

    await this.gcCapacityPlanningEditCalendar.waitUntilPresent(true);
  }
}

export class GanttChartCapacityPlanningEditCalendar extends GanttChartSOP {
  public static readonly title = 'Capacity Planning Edit Calendar';

  public constructor() {
    super('LibCal_dlgEditCalendar', 'gcCalendar');
  }
}

const ganttChartCapacityPlanningEditCalendarContextMenuItem = {
  DeleteEventRow: { ContextMenu: 'cmRow', Name: 'mnuRowDeleteEvent', Label: 'Delete Event' },
  EditEventRow: { ContextMenu: 'cmRow', Name: 'mnuRowEditEvent', Label: 'Edit Event' },
};

export { ganttChartCapacityPlanningEditCalendarContextMenuItem as GanttChartCapacityPlanningEditCalendarContextMenuItem };

/**
 * Expected tooltip for context menu item disabled.
 */
export const contextMenuItemDisabledTooltip = {
  notEvent: (): string => 'The selection is not an event.',
};
